<?php

namespace Drupal\klipfolio_field\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\FormatterBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Plugin implementation of the 'klipfolio_field_formatter' formatter.
 *
 * @FieldFormatter(
 *   id = "klipfolio_field_formatter",
 *   label = @Translation("Klipfolio widget"),
 *   field_types = {
 *     "klipfolio"
 *   }
 * )
 */
class KlipfolioFieldFormatter extends FormatterBase {

  /**
   * {@inheritdoc}
   */
  public static function defaultSettings() {
    return [
      'width' => 400,
      'theme' => 'Light',
      // Implement default settings.
    ] + parent::defaultSettings();
  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, FormStateInterface $form_state) {
    $form = parent::settingsForm($form, $form_state);
    $form['width'] = [
      '#type' => 'number',
      '#title' => $this->t('Width in pixels'),
      '#default_value' => $this->getSetting('width'),
      '#required' => TRUE,
      '#min' => 1,
    ];
    $form['theme'] = [
      '#type' => 'select',
      '#options' => ['Light' => $this->t('Light'), 'Dark' => $this->t('Dark')],
      '#title' => t('Theme'),
      '#default_value' => $this->getSetting('theme'),
      '#required' => TRUE,
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function settingsSummary() {
    $settings = $this->getSettings();
    $summary[] = t('Theme: @theme, width: @width pixels', ['@width' => $settings['width'], '@theme' => $settings['theme']]);
    return $summary;
  }

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {
    $elements = [];
    $settings = $this->getSettings();

    foreach ($items as $delta => $item) {
      $elements[$delta] = [
        '#attached' => [
          'library' => [
            'klipfolio_field/klipfolio_field',
          ],
        ],
        '#theme' => 'klipfolio_field',
        '#attributes' => [
          'class' => ['klipfolio-container'],
          'id' => 'kf-embed-container-' . $item->value,
          'data-klipfolio-id' => $item->value,
          'data-klipfolio-width' => $settings['width'],
          'data-klipfolio-theme' => $settings['theme'],
          'data-klipfolio-title' => $item->title,
        ],
      ];
    }

    return $elements;
  }

}
